<?php

namespace Drupal\Tests\pdf_using_mpdf\Functional;

/**
 * Functional access tests class.
 *
 * @package Drupal\Tests\pdf_using_mpdf\Functional
 */
class PdfUsingMpdfMenuAccessTest extends PdfUsingMpdfTestBase {

  /**
   * Test if user has access to menu item 'Generate PDF' on a node.
   */
  public function testMenuAccess() {
    $edit = [];

    // Log in as administrator.
    $this->drupalLogin($this->adminUser);

    // Assign permissions to authenticated user only for `type_a`.
    $edit = [
      'authenticated[generate type_a pdf]' => TRUE,
      'anonymous[generate type_a pdf]' => TRUE,
    ];
    $this->drupalGet('admin/people/permissions/module/pdf_using_mpdf');
    $this->submitForm($edit, 'Save permissions');
    $this->assertSession()->pageTextContains('The changes have been saved.');

    // Create nodes.
    $node_type_a = $this->createNode(['type' => 'type_a']);
    $node_type_b = $this->createNode(['type' => 'type_b']);
    $this->drupalLogout();

    // Login as authenticated user.
    $this->drupalLogin($this->accessUser);

    // Authenticated user has access to menu item.
    $this->drupalGet('node/' . $node_type_a->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(200);

    // Authenticated user does not have access to menu item.
    $this->drupalGet('node/' . $node_type_b->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(403);
    $this->drupalLogout();

    // Anonymous user has access to menu item.
    $this->drupalGet('node/' . $node_type_a->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(200);

    // Anonymous user does not have access to menu item.
    $this->drupalGet('node/' . $node_type_b->id() . '/pdf');
    $this->assertSession()->statusCodeEquals(403);
  }

}
